@@ -1,4 +1,3 @@
-
 use crate::handler::InteractionHandler;
 use crate::security::*;
 use crate::types;
@@ -6,9 +5,10 @@ use crate::types::interaction::{
     Context, InteractionResponse, InteractionResponseBuilder, InteractionResponseType,
 };
 use crate::*;
-use log::error;
+
 use actix_web::{http, test, web, App, HttpRequest};
 use ed25519_dalek::PublicKey;
+use log::error;
 
 /*const TEST_PUB_KEY: [u8; PUBLIC_KEY_LENGTH] = [
     0x82, 0xd8, 0xd9, 0x7f, 0xe0, 0x64, 0x1e, 0x68, 0xa1, 0xb0, 0xb1, 0x12, 0x20, 0xf0, 0x5e, 0x9e,
@@ -16,7 +16,6 @@ use ed25519_dalek::PublicKey;
 ];*/
 
 const TEST_PUB_KEY: &str = "82d8d97fe0641e68a1b0b11220f05e9ea0539a0cdc002119d4a9e9e025aba1e9";
-#[cfg(feature="extended-handler")]
 const EMPTY_TOKEN: &str = "";
 /*------------------------------
 SECURITY TESTS
@@ -90,19 +89,17 @@ macro_rules! interaction_app_init {
         .await;
     };
 }
-#[cfg(all(feature="handler", not(feature="extended-handler")))]
-macro_rules! init_handler{
+#[cfg(all(feature = "handler", not(feature = "extended-handler")))]
+macro_rules! init_handler {
     () => {
-        
-        InteractionHandler::new(TEST_PUB_KEY)
+        InteractionHandler::new(TEST_PUB_KEY, None)
     };
 }
 
-#[cfg(feature="extended-handler")]
-macro_rules! init_handler{
+#[cfg(feature = "extended-handler")]
+macro_rules! init_handler {
     () => {
-        
-        InteractionHandler::new(TEST_PUB_KEY, EMPTY_TOKEN)
+        InteractionHandler::new(TEST_PUB_KEY, Some(EMPTY_TOKEN))
     };
 }
 
@@ -285,14 +282,16 @@ async fn normal_handle_value_test(ctx: Context) -> InteractionResponse {
 #[allow(unused_must_use)]
 #[slash_command_test]
 async fn normal_handle_direct_test(_: Context) -> InteractionResponse {
-    return InteractionResponseBuilder::default().content("TEST").finish();
+    return InteractionResponseBuilder::default()
+        .content("TEST")
+        .finish();
 }
 
 #[actix_rt::test]
 async fn interactions_normal_handle_test() {
     let mut ih = init_handler!();
 
-    ih.add_command("test", normal_handle_test);
+    ih.add_global_command("test", normal_handle_test);
 
     let mut app = interaction_app_init!(ih);
 
@@ -320,7 +319,7 @@ async fn interactions_normal_handle_test() {
 async fn interactions_normal_from_value_handle_test() {
     let mut ih = init_handler!();
 
-    ih.add_command("test", normal_handle_direct_test);
+    ih.add_global_command("test", normal_handle_direct_test);
 
     let mut app = interaction_app_init!(ih);
 
@@ -348,7 +347,7 @@ async fn interactions_normal_from_value_handle_test() {
 async fn interactions_normal_from_direct_call_handle_test() {
     let mut ih = init_handler!();
 
-    ih.add_command("test", normal_handle_value_test);
+    ih.add_global_command("test", normal_handle_value_test);
 
     let mut app = interaction_app_init!(ih);
 
@@ -374,7 +373,6 @@ async fn interactions_normal_from_direct_call_handle_test() {
 
 use crate::types::interaction::WebhookMessage;
 
-
 #[slash_command_test]
 #[defer]
 async fn deffered_handle_test(ctx: Context) -> InteractionResponse {
@@ -391,14 +389,16 @@ async fn deffered_handle_value_test(ctx: Context) -> InteractionResponse {
 #[slash_command_test]
 #[defer]
 async fn deffered_handle_direct_test(_ctx: Context) -> InteractionResponse {
-    return InteractionResponseBuilder::default().content("TEST").finish();
+    return InteractionResponseBuilder::default()
+        .content("TEST")
+        .finish();
 }
 
 #[actix_rt::test]
 async fn interactions_deffered_handle_test() {
     let mut ih = init_handler!();
 
-    ih.add_command("test", deffered_handle_test);
+    ih.add_global_command("test", deffered_handle_test);
 
     let mut app = interaction_app_init!(ih);
 
@@ -427,7 +427,7 @@ async fn interactions_deffered_handle_test() {
 async fn interactions_deffered_from_value_handle_test() {
     let mut ih = init_handler!();
 
-    ih.add_command("test", deffered_handle_value_test);
+    ih.add_global_command("test", deffered_handle_value_test);
 
     let mut app = interaction_app_init!(ih);
 
@@ -456,7 +456,7 @@ async fn interactions_deffered_from_value_handle_test() {
 async fn interactions_deffered_from_direct_value_handle_test() {
     let mut ih = init_handler!();
 
-    ih.add_command("test", deffered_handle_direct_test);
+    ih.add_global_command("test", deffered_handle_direct_test);
 
     let mut app = interaction_app_init!(ih);
 
@@ -479,4 +479,4 @@ async fn interactions_deffered_from_direct_value_handle_test() {
     //let expected_res = HttpResponse::build(StatusCode::OK).json(expected_data);
 
     assert_eq!(res, expected_data);
-}
\ No newline at end of file
+}
